/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.common;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;



/**
 * Class representing configuration of PostScript renderer (RIP). This
 * configuration is usually stored in a file named
 * "postscript_renderer.properties".
 * 
 * @author Pavel Tisnovsky
 */
public class PostScriptRendererConfiguration
{
    /**
     * Property file containing configuration of PostScript renderer.
     */
    private static final String PROPERTIES_FILE_NAME = "postscript_renderer.properties";

    /**
     * Name of program used as software RIP.
     */
    private String rendererName = "gs";

    /**
     * Renderer options passed via command line.
     */
    private String rendererOptions = "";

    /**
     * Resolution of the image (not its width and height!).
     */
    private int dpi = 150;

    /**
     * Constructor which read renderer configuration from property file.
     */
    public PostScriptRendererConfiguration()
    {
        readConfiguration();
    }

    /**
     * Read renderer configuration from property file.
     */
    private void readConfiguration()
    {
        // Read properties file.
        FileInputStream fileInputStream = null;
        try
        {
            fileInputStream = new FileInputStream(PROPERTIES_FILE_NAME);
            readAllProperties(fileInputStream);
        }
        catch (FileNotFoundException e)
        {
            e.printStackTrace();
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
        finally
        {
            // try to close input stream containing property information
            if (fileInputStream != null)
            {
                try
                {
                    fileInputStream.close();
                }
                catch (IOException e)
                {
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * Read renderer configuration from property file and set all attributes.
     * 
     * @param fileInputStream
     * @throws IOException
     */
    private void readAllProperties(FileInputStream fileInputStream) throws IOException
    {
        Properties properties = new Properties();
        properties.load(fileInputStream);
        this.setRendererName(properties.getProperty("renderer_name"));
        this.setRendererOptions(properties.getProperty("renderer_options"));
        this.setDpi(Integer.parseInt(properties.getProperty("dpi")));
    }

    /**
     * Getter for an attribute rendererName.
     *
     * @return the rendererName
     */
    public String getRendererName()
    {
        return this.rendererName;
    }

    /**
     * Setter for an attribute rendererName.
     *
     * @param rendererName the rendererName to set
     */
    public void setRendererName(String rendererName)
    {
        this.rendererName = rendererName;
    }

    /**
     * Getter for an attribute rendererOptions.
     *
     * @return the rendererOptions
     */
    public String getRendererOptions()
    {
        return this.rendererOptions;
    }

    /**
     * Setter for an attribute rendererOptions.
     *
     * @param rendererOptions the rendererOptions to set
     */
    public void setRendererOptions(String rendererOptions)
    {
        this.rendererOptions = rendererOptions;
    }

    /**
     * Getter for an attribute dpi.
     *
     * @return the dpi
     */
    public int getDpi()
    {
        return this.dpi;
    }

    /**
     * Setter for an attribute dpi.
     *
     * @param dpi the dpi to set
     */
    public void setDpi(int dpi)
    {
        this.dpi = dpi;
    }
}
